@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Procman - main window
  * Copyright (C) 2001 Kevin Vandersloot
  *
@@ -26,8 +27,6 @@
 
 void            create_main_window (ProcmanApp *app);
 void            update_sensitivity (ProcmanApp *app);
-void            block_priority_changed_handlers(ProcmanApp *app, bool block);
 void            do_popup_menu(ProcmanApp *app, GdkEventButton *event);
-GtkWidget *     make_title_label (const char *text);
 
 #endif /* _PROCMAN_INTERFACE_H_ */
