@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <gdkmm/pixbuf.h>
@@ -9,7 +10,6 @@
 #include <dirent.h>
 #include <string.h>
 #include <time.h>
-#include <gdk/gdkx.h>
 
 #include <glib/gi18n.h>
 
@@ -76,7 +76,7 @@ void draw_background(LoadGraph *graph) {
     PangoLayout* layout;
     PangoFontDescription* font_desc;
     PangoRectangle extents;
-    GdkRGBA fg, bg;
+    GdkRGBA fg;
 
     num_bars = graph->num_bars();
     graph->graph_dely = (graph->draw_height - 15) / num_bars; /* round to int to avoid AA blur */
@@ -86,21 +86,18 @@ void draw_background(LoadGraph *graph) {
 
     gtk_widget_get_allocation (graph->disp, &allocation);
     graph->background = gdk_window_create_similar_surface (gtk_widget_get_window (graph->disp),
-                                                           CAIRO_CONTENT_COLOR,
+                                                           CAIRO_CONTENT_COLOR_ALPHA,
                                                            allocation.width,
                                                            allocation.height);
     cr = cairo_create (graph->background);
 
-    GtkStyleContext *context = gtk_widget_get_style_context (ProcmanApp::get()->notebook);
-    gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &bg);
+    GtkStyleContext *context = gtk_widget_get_style_context (ProcmanApp::get()->stack);
+    
     gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &fg);
 
-    // set the background colour
-    gdk_cairo_set_source_rgba (cr, &bg);
-    cairo_paint (cr);
-
+    cairo_paint_with_alpha (cr, 0.0);
     layout = pango_cairo_create_layout (cr);
-    font_desc = pango_font_description_copy (gtk_style_context_get_font (context, GTK_STATE_FLAG_NORMAL));
+    gtk_style_context_get (context, GTK_STATE_FLAG_NORMAL, GTK_STYLE_PROPERTY_FONT, &font_desc, NULL);
     pango_font_description_set_size (font_desc, 0.8 * graph->fontsize * PANGO_SCALE);
     pango_layout_set_font_description (layout, font_desc);
     pango_font_description_free (font_desc);
@@ -215,6 +212,20 @@ load_graph_configure (GtkWidget *widget,
     return TRUE;
 }
 
+static gboolean
+load_graph_state_changed (GtkWidget *widget,
+                      GtkStateFlags *flags,
+                      gpointer data_ptr)
+{
+    LoadGraph * const graph = static_cast<LoadGraph*>(data_ptr);
+
+    graph->clear_background();
+
+    load_graph_queue_draw (graph);
+
+    return TRUE;
+}
+
 static gboolean
 load_graph_draw (GtkWidget *widget,
                  cairo_t * context,
@@ -289,6 +300,12 @@ load_graph_draw (GtkWidget *widget,
     return TRUE;
 }
 
+void
+load_graph_reset (LoadGraph *graph)
+{
+    std::fill(graph->data_block.begin(), graph->data_block.end(), -1.0f);
+}
+
 static void
 get_load (LoadGraph *graph)
 {
@@ -782,6 +799,8 @@ LoadGraph::LoadGraph(guint type)
                       G_CALLBACK (load_graph_configure), graph);
     g_signal_connect (G_OBJECT(disp), "destroy",
                       G_CALLBACK (load_graph_destroy), graph);
+    g_signal_connect (G_OBJECT(disp), "state-flags-changed",
+                      G_CALLBACK (load_graph_state_changed), graph);
 
     gtk_widget_set_events (disp, GDK_EXPOSURE_MASK);
 
