@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #ifndef _PROCMAN_LOAD_GRAPH_H_
 #define _PROCMAN_LOAD_GRAPH_H_
 
@@ -110,6 +111,10 @@ void
 load_graph_change_speed (LoadGraph *g,
                          guint new_speed);
 
+/* Clear the history data. */
+void
+load_graph_reset (LoadGraph *g);
+
 LoadGraphLabels*
 load_graph_get_labels (LoadGraph *g) G_GNUC_CONST;
 
