@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #ifndef _PROCMAN_PRETTYTABLE_H_
 #define _PROCMAN_PRETTYTABLE_H_
 
@@ -11,10 +12,12 @@
 #include <map>
 #include <string>
 
+#ifdef HAVE_WNCK
 extern "C" {
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 }
+#endif
 
 #include "iconthemewrapper.h"
 
@@ -34,17 +37,20 @@ public:
 
 private:
 
+#ifdef HAVE_WNCK
     static void on_application_opened(WnckScreen* screen, WnckApplication* app, gpointer data);
     static void on_application_closed(WnckScreen* screen, WnckApplication* app, gpointer data);
 
     void register_application(pid_t pid, Glib::RefPtr<Gdk::Pixbuf> icon);
     void unregister_application(pid_t pid);
-
+#endif
 
     Glib::RefPtr<Gdk::Pixbuf> get_icon_from_theme(const ProcInfo &);
     Glib::RefPtr<Gdk::Pixbuf> get_icon_from_default(const ProcInfo &);
     Glib::RefPtr<Gdk::Pixbuf> get_icon_from_gio(const ProcInfo &);
+#ifdef HAVE_WNCK
     Glib::RefPtr<Gdk::Pixbuf> get_icon_from_wnck(const ProcInfo &);
+#endif
     Glib::RefPtr<Gdk::Pixbuf> get_icon_from_name(const ProcInfo &);
     Glib::RefPtr<Gdk::Pixbuf> get_icon_for_kernel(const ProcInfo &);
     Glib::RefPtr<Gdk::Pixbuf> get_icon_dummy(const ProcInfo &);
