@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Procman - dialogs
  * Copyright (C) 2001 Kevin Vandersloot
  *
@@ -28,7 +29,6 @@
 
 #include "procdialogs.h"
 #include "proctable.h"
-#include "callbacks.h"
 #include "prettytable.h"
 #include "procactions.h"
 #include "util.h"
@@ -105,7 +105,7 @@ procdialog_create_kill_dialog (ProcmanApp *app, int signal)
                                               secondary);
 
     gtk_dialog_add_buttons (GTK_DIALOG (kill_alert_dialog),
-                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            _("_Cancel"), GTK_RESPONSE_CANCEL,
                             button_text, GTK_RESPONSE_OK,
                             NULL);
 
@@ -161,10 +161,8 @@ procdialog_create_renice_dialog (ProcmanApp *app)
     if (!info)
         return;
 
-    gchar* filename = g_build_filename (GSM_DATA_DIR, "renice.ui", NULL);
-
     builder = gtk_builder_new();
-    gtk_builder_add_from_file (builder, filename, NULL);
+    gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/renice.ui", NULL);
 
     renice_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "renice_dialog"));
 
@@ -204,7 +202,6 @@ procdialog_create_renice_dialog (ProcmanApp *app)
     gtk_builder_connect_signals (builder, NULL);
 
     g_object_unref (G_OBJECT (builder));
-    g_free (filename);
 }
 
 static void
@@ -405,10 +402,8 @@ procdialog_create_preferences_dialog (ProcmanApp *app)
     if (prefs_dialog)
         return;
 
-    gchar* filename = g_build_filename (GSM_DATA_DIR, "preferences.ui", NULL);
-
     builder = gtk_builder_new();
-    gtk_builder_add_from_file (builder, filename, NULL);
+    gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/preferences.ui", NULL);
 
     prefs_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "preferences_dialog"));
 
@@ -473,21 +468,16 @@ procdialog_create_preferences_dialog (ProcmanApp *app)
     g_signal_connect (G_OBJECT (prefs_dialog), "response",
                       G_CALLBACK (prefs_dialog_button_pressed), app);
 
-    switch (app->config.current_tab) {
-        case PROCMAN_TAB_PROCESSES:
-            gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 0);
-            break;
-        case PROCMAN_TAB_RESOURCES:
-            gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
-            break;
-        case PROCMAN_TAB_DISKS:
-            gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 2);
-            break;
+    const char* current_tab = g_settings_get_string (app->settings, "current-tab");
+    if (strcmp (current_tab, "processes") == 0)
+        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 0);
+    else if (strcmp (current_tab, "resources") == 0)
+        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
+    else if (strcmp (current_tab, "disks") == 0)
+        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 2);
 
-    }
     gtk_builder_connect_signals (builder, NULL);
     g_object_unref (G_OBJECT (builder));
-    g_free (filename);
 }
 
 
