@@ -1,49 +1,30 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <glib/gi18n.h>
 #include <glibtop.h>
 #include <glibtop/close.h>
+#include <signal.h>
 
 #include "procman-app.h"
+#include "procdialogs.h"
 #include "interface.h"
 #include "proctable.h"
-#include "callbacks.h"
 #include "load-graph.h"
 #include "settings-keys.h"
 #include "argv.h"
 #include "util.h"
 #include "cgroups.h"
+#include "lsof.h"
+#include "disks.h"
 
 static void
-mount_changed(const Glib::RefPtr<Gio::Mount>&, ProcmanApp *app)
-{
-    cb_update_disks(app);
-}
-
-
-static void
-init_volume_monitor(ProcmanApp *app)
-{
-    using namespace Gio;
-    using namespace Glib;
-
-    RefPtr<VolumeMonitor> monitor = VolumeMonitor::get();
-
-    monitor->signal_mount_added().connect(sigc::bind<ProcmanApp *>(sigc::ptr_fun(&mount_changed), app));
-    monitor->signal_mount_changed().connect(sigc::bind<ProcmanApp *>(sigc::ptr_fun(&mount_changed), app));
-    monitor->signal_mount_removed().connect(sigc::bind<ProcmanApp *>(sigc::ptr_fun(&mount_changed), app));
-}
-
-static void
-tree_changed_cb (GSettings *settings, const gchar *key, gpointer data)
+cb_show_dependencies_changed (GSettings *settings, const gchar *key, gpointer data)
 {
     ProcmanApp *app = static_cast<ProcmanApp *>(data);
 
-    app->config.show_tree = g_settings_get_boolean(settings, key);
-
-    g_object_set(G_OBJECT(app->tree),
-                 "show-expanders", app->config.show_tree,
-                 NULL);
+    gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (app->tree),
+                                      g_settings_get_boolean (settings, "show-dependencies"));
 
     proctable_clear_tree (app);
     proctable_update_all (app);
@@ -66,6 +47,7 @@ draw_stacked_changed_cb(GSettings *settings, const gchar *key, gpointer data)
 
     app->config.draw_stacked = g_settings_get_boolean(settings, key);
     app->cpu_graph->clear_background();
+    load_graph_reset(app->cpu_graph);
 }
 
 
@@ -80,26 +62,14 @@ network_in_bits_changed_cb(GSettings *settings, const gchar *key, gpointer data)
 }
 
 static void
-view_as_changed_cb (GSettings *settings, const gchar *key, gpointer data)
+cb_show_whose_processes_changed (GSettings *settings, const gchar *key, gpointer data)
 {
     ProcmanApp *app = static_cast<ProcmanApp *>(data);
 
-    app->config.whose_process = g_settings_get_int (settings, key);
-    app->config.whose_process = CLAMP (app->config.whose_process, 0, 2);
     proctable_clear_tree (app);
     proctable_update_all (app);
 }
 
-static void
-warning_changed_cb (GSettings *settings, const gchar *key, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-
-    if (g_str_equal (key, "kill-dialog")) {
-        app->config.show_kill_warning = g_settings_get_boolean (settings, key);
-    }
-}
-
 static void
 timeouts_changed_cb (GSettings *settings, const gchar *key, gpointer data)
 {
@@ -112,12 +82,7 @@ timeouts_changed_cb (GSettings *settings, const gchar *key, gpointer data)
 
         app->smooth_refresh->reset();
 
-        if(app->timeout) {
-            g_source_remove (app->timeout);
-            app->timeout = g_timeout_add (app->config.update_interval,
-                                          cb_timeout,
-                                          app);
-        }
+        proctable_reset_timeout (app);
     }
     else if (g_str_equal (key, "graph-update-interval")){
         app->config.graph_update_interval = g_settings_get_int (settings, key);
@@ -137,13 +102,7 @@ timeouts_changed_cb (GSettings *settings, const gchar *key, gpointer data)
         app->config.disks_update_interval =
             MAX (app->config.disks_update_interval, 1000);
 
-        if(app->disk_timeout) {
-            g_source_remove (app->disk_timeout);
-            app->disk_timeout = \
-                g_timeout_add (app->config.disks_update_interval,
-                               cb_update_disks,
-                               app);
-        }
+        disks_reset_timeout (app);
     }
     else {
         g_assert_not_reached();
@@ -237,7 +196,7 @@ show_all_fs_changed_cb (GSettings *settings, const gchar *key, gpointer data)
 
     app->config.show_all_fs = g_settings_get_boolean (settings, key);
 
-    cb_update_disks (app);
+    disks_update (app);
 }
 
 void
@@ -256,8 +215,7 @@ ProcmanApp::load_settings()
     config.ypos = g_settings_get_int (settings, "y-position");
     config.maximized = g_settings_get_boolean (settings, "maximized");
 
-    config.show_tree = g_settings_get_boolean (settings, "show-tree");
-    g_signal_connect (G_OBJECT(settings), "changed::show-tree", G_CALLBACK(tree_changed_cb), this);
+    g_signal_connect (G_OBJECT(settings), "changed::show-dependencies", G_CALLBACK(cb_show_dependencies_changed), this);
 
     config.solaris_mode = g_settings_get_boolean(settings, procman::settings::solaris_mode.c_str());
     std::string detail_string("changed::" + procman::settings::solaris_mode);
@@ -271,8 +229,6 @@ ProcmanApp::load_settings()
     detail_string = "changed::" + procman::settings::network_in_bits;
     g_signal_connect(G_OBJECT(settings), detail_string.c_str(), G_CALLBACK(network_in_bits_changed_cb), this);
 
-    config.show_kill_warning = g_settings_get_boolean (settings, "kill-dialog");
-    g_signal_connect (G_OBJECT(settings), "changed::kill-dialog", G_CALLBACK(warning_changed_cb), this);
     config.update_interval = g_settings_get_int (settings, "update-interval");
     g_signal_connect (G_OBJECT(settings), "changed::update-interval", G_CALLBACK(timeouts_changed_cb), this);
     config.graph_update_interval = g_settings_get_int (settings,
@@ -288,9 +244,7 @@ ProcmanApp::load_settings()
     g_signal_connect (settings, "changed::show-all-fs", G_CALLBACK(show_all_fs_changed_cb), this);
 
 
-    config.whose_process = g_settings_get_int (settings, "view-as");
-    g_signal_connect (G_OBJECT(settings), "changed::view-as", G_CALLBACK(view_as_changed_cb), this);
-    config.current_tab = g_settings_get_int (settings, "current-tab");
+    g_signal_connect (G_OBJECT(settings), "changed::show-whose-processes", G_CALLBACK(cb_show_whose_processes_changed), this);
 
     /* Determine number of cpus since libgtop doesn't really tell you*/
     config.num_cpus = 0;
@@ -349,10 +303,6 @@ ProcmanApp::load_settings()
     config.update_interval = MAX (config.update_interval, 1000);
     config.graph_update_interval = MAX (config.graph_update_interval, 250);
     config.disks_update_interval = MAX (config.disks_update_interval, 1000);
-    config.whose_process = CLAMP (config.whose_process, 0, 2);
-    config.current_tab = CLAMP(config.current_tab,
-                               PROCMAN_TAB_PROCESSES,
-                               PROCMAN_TAB_DISKS);
 }
 
 ProcmanApp::ProcmanApp() : Gtk::Application("org.gnome.SystemMonitor", Gio::APPLICATION_HANDLES_COMMAND_LINE)
@@ -376,10 +326,29 @@ void ProcmanApp::on_activate()
 }
 
 static void
-set_tab(GtkNotebook* notebook, gint tab, ProcmanApp *app)
+cb_header_menu_position_function (GtkMenu* menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 {
-    gtk_notebook_set_current_page(notebook, tab);
-    cb_change_current_page(notebook, tab, app);
+    GdkEventButton* event = (GdkEventButton *) data;
+    gint wx, wy, ww, wh;
+    gdk_window_get_geometry(event->window, &wx, &wy, &ww, &wh);
+    gdk_window_get_origin(event->window, &wx, &wy);
+
+    *x = wx + event->x;
+    *y = wy + wh;
+    *push_in = TRUE;
+}
+
+static gboolean
+cb_column_header_clicked (GtkTreeViewColumn* column, GdkEvent* event, gpointer data)
+{
+    GtkMenu *menu = (GtkMenu *) data;
+
+    if (event->button.button == GDK_BUTTON_SECONDARY) {
+        gtk_menu_popup(GTK_MENU(menu), NULL, NULL, cb_header_menu_position_function, &(event->button), event->button.button, event->button.time);
+        return TRUE;
+    }
+
+    return FALSE;
 }
 
 gboolean
@@ -418,7 +387,6 @@ procman_get_tree_state (GSettings *settings, GtkWidget *tree, const gchar *child
         {
             GtkTreeViewColumn *column;
             gint width;
-            gboolean visible;
             int id;
             const gchar *title;
             gchar *key;
@@ -428,18 +396,8 @@ procman_get_tree_state (GSettings *settings, GtkWidget *tree, const gchar *child
             column = static_cast<GtkTreeViewColumn*>(it->data);
             id = gtk_tree_view_column_get_sort_column_id (column);
 
-            key = g_strdup_printf ("col-%d-width", id);
-            g_settings_get (pt_settings, key, "i", &width);
-            g_free (key);
-
-            key = g_strdup_printf ("col-%d-visible", id);
-            visible = g_settings_get_boolean (pt_settings, key);
-            g_free (key);
-
-            column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), id);
-            if(!column) continue;
-            gtk_tree_view_column_set_visible (column, visible);
             /* ensure column is really visible */
+            width = gtk_tree_view_column_get_fixed_width(column);
             width = MAX(width, 50);
             gtk_tree_view_column_set_fixed_width(column, width);
 
@@ -562,8 +520,6 @@ ProcmanApp::save_config ()
     g_settings_set_int (settings, "y-position", config.ypos);
     g_settings_set_boolean (settings, "maximized", config.maximized);
 
-    g_settings_set_int (settings, "current-tab", config.current_tab);
-
     g_settings_sync ();
 }
 
@@ -586,21 +542,19 @@ int ProcmanApp::on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>&
 
     g_strfreev(argv);
 
-    if (option_group.show_processes_tab) {
-        procman_debug("Starting with PROCMAN_TAB_PROCESSES by commandline request");
-        set_tab(GTK_NOTEBOOK(notebook), PROCMAN_TAB_PROCESSES, this);
-    } else if (option_group.show_resources_tab) {
-        procman_debug("Starting with PROCMAN_TAB_RESOURCES by commandline request");
-        set_tab(GTK_NOTEBOOK(notebook), PROCMAN_TAB_RESOURCES, this);
-    } else if (option_group.show_file_systems_tab) {
-        procman_debug("Starting with PROCMAN_TAB_DISKS by commandline request");
-        set_tab(GTK_NOTEBOOK(notebook), PROCMAN_TAB_DISKS, this);
-    } else if (option_group.print_version) {
+    if (option_group.print_version) {
         g_print("%s %s\n", _("GNOME System Monitor"), VERSION);
-	exit (EXIT_SUCCESS);
-	return 0;
+        exit (EXIT_SUCCESS);
     }
 
+    if (option_group.show_processes_tab)
+        g_settings_set_string (settings, "current-tab", "processes");
+    else if (option_group.show_resources_tab)
+        g_settings_set_string (settings, "current-tab", "resources");
+    else if (option_group.show_file_systems_tab)
+        g_settings_set_string (settings, "current-tab", "disks");
+    else if (option_group.print_version)
+
     on_activate ();
 
     return 0;
@@ -609,19 +563,23 @@ int ProcmanApp::on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>&
 void
 ProcmanApp::on_help_activate(const Glib::VariantBase&)
 {
-    cb_help_contents (NULL, this);
+    GError* error = 0;
+    if (!g_app_info_launch_default_for_uri("help:gnome-system-monitor", NULL, &error)) {
+        g_warning("Could not display help : %s", error->message);
+        g_error_free(error);
+    }
 }
 
 void
 ProcmanApp::on_lsof_activate(const Glib::VariantBase&)
 {
-    cb_show_lsof (NULL, this);
+    procman_lsof(this);
 }
 
 void
 ProcmanApp::on_preferences_activate(const Glib::VariantBase&)
 {
-    cb_edit_preferences (NULL, this);
+    procdialog_create_preferences_dialog (this);
 }
 
 void
@@ -671,13 +629,19 @@ void ProcmanApp::on_startup()
     action->signal_activate().connect(sigc::mem_fun(*this, &ProcmanApp::on_preferences_activate));
     add_action(action);
 
-    char* filename = g_build_filename (GSM_DATA_DIR, "menus.ui", NULL);
-    Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_file(filename);
-    g_free (filename);
+    Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_resource("/org/gnome/gnome-system-monitor/data/menus.ui");
 
     Glib::RefPtr<Gio::Menu> menu = Glib::RefPtr<Gio::Menu>::cast_static(builder->get_object ("app-menu"));
     set_app_menu (menu);
 
+    add_accelerator("<Primary>d", "win.show-dependencies", NULL);
+    add_accelerator("<Primary>s", "win.send-signal-stop", g_variant_new_int32(SIGSTOP));
+    add_accelerator("<Primary>c", "win.send-signal-cont", g_variant_new_int32(SIGCONT));
+    add_accelerator("<Primary>e", "win.send-signal-end", g_variant_new_int32(SIGTERM));
+    add_accelerator("<Primary>k", "win.send-signal-kill", g_variant_new_int32 (SIGKILL));
+    add_accelerator("<Primary>m", "win.memory-maps", NULL);
+    add_accelerator("<Primary>f", "win.open-files", NULL);
+
     Gtk::Window::set_default_icon_name ("utilities-system-monitor");
 
     glibtop_init ();
@@ -689,7 +653,10 @@ void ProcmanApp::on_startup()
 
     create_main_window (this);
 
-    init_volume_monitor (this);
+    add_accelerator ("<Alt>1", "win.show-page", g_variant_new_string ("processes"));
+    add_accelerator ("<Alt>2", "win.show-page", g_variant_new_string ("resources"));
+    add_accelerator ("<Alt>3", "win.show-page", g_variant_new_string ("disks"));
+    add_accelerator ("<Primary>r", "win.refresh", NULL);
 
     gtk_widget_show (main_window);
 }
