@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Process properties dialog
  * Copyright (C) 2010 Krishnan Parthasarathi <krishnan.parthasarathi@gmail.com>
  *                    Robert Ancell <robert.ancell@canonical.com>
@@ -26,7 +27,7 @@
 #include <glibtop/procstate.h>
 #if defined (__linux__)
 #include <asm/param.h>
-#elif defined (__OpenBSD__)
+#elif defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #endif
@@ -48,55 +49,6 @@ typedef struct _proc_arg {
     gchar *val;
 } proc_arg;
 
-static void
-get_process_memory_writable (ProcInfo *info)
-{
-    glibtop_proc_map buf;
-    glibtop_map_entry *maps;
-
-    maps = glibtop_get_proc_map(&buf, info->pid);
-
-    gulong memwritable = 0;
-    const unsigned number = buf.number;
-
-    for (unsigned i = 0; i < number; ++i) {
-#ifdef __linux__
-        memwritable += maps[i].private_dirty;
-#else
-        if (maps[i].perm & GLIBTOP_MAP_PERM_WRITE)
-            memwritable += maps[i].size;
-#endif
-    }
-
-    info->memwritable = memwritable;
-
-    g_free(maps);
-}
-
-static void
-get_process_memory_info (ProcInfo *info)
-{
-    glibtop_proc_mem procmem;
-    WnckResourceUsage xresources;
-
-    wnck_pid_read_resource_usage (gdk_screen_get_display (gdk_screen_get_default ()),
-                                  info->pid,
-                                  &xresources);
-
-    glibtop_get_proc_mem(&procmem, info->pid);
-
-    info->vmsize	= procmem.vsize;
-    info->memres	= procmem.resident;
-    info->memshared	= procmem.share;
-
-    info->memxserver = xresources.total_bytes_estimate;
-
-    get_process_memory_writable(info);
-
-    // fake the smart memory column if writable is not available
-    info->mem = info->memxserver + (info->memwritable ? info->memwritable : info->memres);
-}
-
 static gchar*
 format_memsize(guint64 size)
 {
@@ -115,7 +67,7 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
     if (!info)
         return;
 
-#if defined (__OpenBSD__)
+#if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
     struct clockinfo cinf;
     size_t size = sizeof (cinf);
     int HZ;
@@ -135,7 +87,9 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
         { N_("Resident Memory"), format_memsize(info->memres)},
         { N_("Writable Memory"), format_memsize(info->memwritable)},
         { N_("Shared Memory"), format_memsize(info->memshared)},
+#ifdef HAVE_WNCK
         { N_("X Server Memory"), format_memsize(info->memxserver)},
+#endif
         { N_("CPU"), g_strdup_printf("%d%%", info->pcpu)},
         { N_("CPU Time"), g_strdup_printf(ngettext("%lld second", "%lld seconds", info->cpu_time/HZ), (unsigned long long)info->cpu_time/HZ) },
         { N_("Started"), g_strdup_printf("%s", ctime((const time_t*)(&info->start_time)))},
@@ -257,7 +211,7 @@ create_single_procproperties_dialog (GtkTreeModel *model, GtkTreePath *path,
 
     procpropdialog = gtk_dialog_new_with_buttons (_("Process Properties"), NULL,
                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                                  _("_Close"), GTK_RESPONSE_CLOSE,
                                                   NULL);
     gtk_window_set_resizable (GTK_WINDOW (procpropdialog), TRUE);
     gtk_window_set_default_size (GTK_WINDOW (procpropdialog), 575, 400);
