@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Procman tree view and process updating
  * Copyright (C) 2001 Kevin Vandersloot
  *
@@ -48,9 +49,13 @@
 #include <systemd/sd-login.h>
 #endif
 
+#ifdef HAVE_WNCK
+#define WNCK_I_KNOW_THIS_IS_UNSTABLE
+#include <libwnck/libwnck.h>
+#endif
+
 #include "procman-app.h"
 #include "proctable.h"
-#include "callbacks.h"
 #include "prettytable.h"
 #include "util.h"
 #include "interface.h"
@@ -184,6 +189,108 @@ cb_proctree_destroying (GtkTreeView *self, gpointer data)
     g_signal_handlers_disconnect_by_func(self, (gpointer) cb_columns_changed, data);
 }
 
+static gboolean
+cb_tree_button_pressed (GtkWidget *widget, GdkEventButton *event, gpointer data)
+{
+    ProcmanApp *app = (ProcmanApp *) data;
+
+    if (gdk_event_triggers_context_menu ((GdkEvent *) event)) {
+        do_popup_menu (app, event);
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+static gboolean
+cb_tree_popup_menu (GtkWidget *widget, gpointer data)
+{
+    ProcmanApp *app = (ProcmanApp *) data;
+
+    do_popup_menu (app, NULL);
+
+    return TRUE;
+}
+
+static void
+get_last_selected (GtkTreeModel *model, GtkTreePath *path,
+                   GtkTreeIter *iter, gpointer data)
+{
+    ProcInfo **info = (ProcInfo**) data;
+
+    gtk_tree_model_get (model, iter, COL_POINTER, info, -1);
+}
+
+void
+cb_row_selected (GtkTreeSelection *selection, gpointer data)
+{
+    ProcmanApp *app = (ProcmanApp *) data;
+
+    app->selection = selection;
+
+    app->selected_process = NULL;
+
+    /* get the most recent selected process and determine if there are
+    ** no selected processes
+    */
+    gtk_tree_selection_selected_foreach (app->selection, get_last_selected,
+                                         &app->selected_process);
+    if (app->selected_process) {
+        GVariant *priority;
+        gint nice = app->selected_process->nice;
+        if (nice < -7)
+            priority = g_variant_new_int32 (-20);
+        else if (nice < -2)
+            priority = g_variant_new_int32 (-5);
+        else if (nice < 3)
+            priority = g_variant_new_int32 (0);
+        else if (nice < 7)
+            priority = g_variant_new_int32 (5);
+        else
+            priority = g_variant_new_int32 (19);
+
+        GAction *action = g_action_map_lookup_action (G_ACTION_MAP (app->main_window),
+                                                      "priority");
+
+        g_action_change_state (action, priority);
+    }
+    update_sensitivity(app);
+}
+
+static gint
+cb_timeout (gpointer data)
+{
+    ProcmanApp *app = (ProcmanApp *) data;
+    guint new_interval;
+
+    proctable_update_all (app);
+
+    if (app->smooth_refresh->get(new_interval)) {
+        app->timeout = g_timeout_add(new_interval,
+                                     cb_timeout,
+                                     app);
+        return G_SOURCE_REMOVE;
+    }
+
+    return G_SOURCE_CONTINUE;
+}
+
+static void
+cb_refresh_icons (GtkIconTheme *theme, gpointer data)
+{
+    ProcmanApp *app = (ProcmanApp *) data;
+
+    if(app->timeout) {
+        g_source_remove (app->timeout);
+    }
+
+    for (ProcInfo::Iterator it(ProcInfo::begin()); it != ProcInfo::end(); ++it) {
+        app->pretty_table->set_icon(*(it->second));
+    }
+
+    cb_timeout(app);
+}
+
 GtkWidget *
 proctable_new (ProcmanApp * const app)
 {
@@ -256,9 +363,8 @@ proctable_new (ProcmanApp * const app)
 
     proctree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
     gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (proctree), COL_TOOLTIP);
-    g_object_set(G_OBJECT(proctree),
-                 "show-expanders", app->config.show_tree,
-                 NULL);
+    gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (proctree),
+                                      g_settings_get_boolean (app->settings, "show-dependencies"));
     gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (proctree),
                                          search_equal_func,
                                          NULL,
@@ -285,36 +391,43 @@ proctable_new (ProcmanApp * const app)
     gtk_tree_view_column_set_title (column, _(titles[0]));
 
     gtk_tree_view_column_set_sort_column_id (column, COL_NAME);
+    bind_column_to_gsetting (settings, column);
     gtk_tree_view_column_set_resizable (column, TRUE);
     gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
     gtk_tree_view_column_set_min_width (column, 1);
     gtk_tree_view_column_set_reorderable(column, TRUE);
-    g_signal_connect(G_OBJECT(column), "notify::width", G_CALLBACK(cb_column_resized), settings);
     gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (proctree), column);
 
     for (i = COL_USER; i <= COL_PRIORITY; i++) {
-
-        GtkCellRenderer *cell;
         GtkTreeViewColumn *col;
+        GtkCellRenderer *cell;
 
+#ifndef HAVE_WNCK
+        if (i == COL_MEMXSERVER) {
+          continue;
+        }
+#endif
         cell = gtk_cell_renderer_text_new();
         col = gtk_tree_view_column_new();
         gtk_tree_view_column_pack_start(col, cell, TRUE);
         gtk_tree_view_column_set_title(col, _(titles[i]));
         gtk_tree_view_column_set_resizable(col, TRUE);
         gtk_tree_view_column_set_sort_column_id(col, i);
-        g_signal_connect(G_OBJECT(col), "notify::width", G_CALLBACK(cb_column_resized), settings);
+        bind_column_to_gsetting (settings, col);
         gtk_tree_view_column_set_reorderable(col, TRUE);
         gtk_tree_view_append_column(GTK_TREE_VIEW(proctree), col);
+
         // type
         switch (i) {
+#ifdef HAVE_WNCK
             case COL_MEMXSERVER:
                 gtk_tree_view_column_set_cell_data_func(col, cell,
                                                         &procman::size_cell_data_func,
                                                         GUINT_TO_POINTER(i),
                                                         NULL);
                 break;
+#endif
             case COL_VMSIZE:
             case COL_MEMRES:
             case COL_MEMSHARED:
@@ -359,7 +472,9 @@ proctable_new (ProcmanApp * const app)
 
         // sorting
         switch (i) {
+#ifdef HAVE_WNCK
             case COL_MEMXSERVER:
+#endif
             case COL_VMSIZE:
             case COL_MEMRES:
             case COL_MEMSHARED:
@@ -388,7 +503,9 @@ proctable_new (ProcmanApp * const app)
             case COL_MEMRES:
             case COL_MEMWRITABLE:
             case COL_MEMSHARED:
+#ifdef HAVE_WNCK
             case COL_MEMXSERVER:
+#endif
             case COL_CPU:
             case COL_NICE:
             case COL_PID:
@@ -566,24 +683,29 @@ static void
 get_process_memory_info(ProcInfo *info)
 {
     glibtop_proc_mem procmem;
+#ifdef HAVE_WNCK
     WnckResourceUsage xresources;
 
     wnck_pid_read_resource_usage (gdk_screen_get_display (gdk_screen_get_default ()),
                                   info->pid,
                                   &xresources);
 
+    info->memxserver = xresources.total_bytes_estimate;
+#endif
+
     glibtop_get_proc_mem(&procmem, info->pid);
 
     info->vmsize    = procmem.vsize;
     info->memres    = procmem.resident;
     info->memshared = procmem.share;
 
-    info->memxserver = xresources.total_bytes_estimate;
-
     get_process_memory_writable(info);
 
     // fake the smart memory column if writable is not available
-    info->mem = info->memxserver + (info->memwritable ? info->memwritable : info->memres);
+    info->mem = info->memwritable ? info->memwritable : info->memres;
+#ifdef HAVE_WNCK
+    info->mem += info->memxserver;
+#endif
 }
 
 
@@ -602,7 +724,9 @@ update_info_mutable_cols(ProcInfo *info)
     tree_store_update(model, &info->node, COL_MEMRES, info->memres);
     tree_store_update(model, &info->node, COL_MEMWRITABLE, info->memwritable);
     tree_store_update(model, &info->node, COL_MEMSHARED, info->memshared);
+#ifdef HAVE_WNCK
     tree_store_update(model, &info->node, COL_MEMXSERVER, info->memxserver);
+#endif
     tree_store_update(model, &info->node, COL_CPU, info->pcpu);
     tree_store_update(model, &info->node, COL_CPU_TIME, info->cpu_time);
     tree_store_update(model, &info->node, COL_START_TIME, info->start_time);
@@ -625,7 +749,7 @@ insert_info_to_tree (ProcInfo *info, ProcmanApp *app, bool forced = false)
 
     model = gtk_tree_view_get_model (GTK_TREE_VIEW (app->tree));
 
-    if (app->config.show_tree) {
+    if (g_settings_get_boolean (app->settings, "show-dependencies")) {
 
         ProcInfo *parent = 0;
 
@@ -875,7 +999,7 @@ refresh_list (ProcmanApp *app, const pid_t* pid_list, const guint n)
     // pid_list == ProcInfo::all + addition
 
 
-    if (app->config.show_tree) {
+    if (g_settings_get_boolean (app->settings, "show-dependencies")) {
 
         // insert process in the tree. walk through the addition list
         // (new process + process that have a new parent). This loop
@@ -950,23 +1074,19 @@ proctable_update_list (ProcmanApp *app)
     pid_t* pid_list;
     glibtop_proclist proclist;
     glibtop_cpu cpu;
-    gint which, arg;
+    int which = 0;
+    int arg = 0;
 
-    switch (app->config.whose_process) {
-        case ALL_PROCESSES:
-            which = GLIBTOP_KERN_PROC_ALL;
-            arg = 0;
-            break;
-
-        case ACTIVE_PROCESSES:
-            which = GLIBTOP_KERN_PROC_ALL | GLIBTOP_EXCLUDE_IDLE;
-            arg = 0;
-            break;
-
-        default:
-            which = GLIBTOP_KERN_PROC_UID;
-            arg = getuid ();
-            break;
+    const char* whose_processes = g_settings_get_string (app->settings, "show-whose-processes");
+    if (strcmp (whose_processes, "all") == 0) {
+        which = GLIBTOP_KERN_PROC_ALL;
+        arg = 0;
+    } else if (strcmp (whose_processes, "active") == 0) {
+        which = GLIBTOP_KERN_PROC_ALL | GLIBTOP_EXCLUDE_IDLE;
+        arg = 0;
+    } else if (strcmp (whose_processes, "user") == 0) {
+      which = GLIBTOP_KERN_PROC_UID;
+      arg = getuid ();
     }
 
     pid_list = glibtop_get_proclist (&proclist, which, arg);
@@ -1081,3 +1201,27 @@ ProcInfo::set_icon(Glib::RefPtr<Gdk::Pixbuf> icon)
                        COL_PIXBUF, (this->pixbuf ? this->pixbuf->gobj() : NULL),
                        -1);
 }
+
+void
+proctable_freeze (ProcmanApp *app)
+{
+    if (app->timeout) {
+      g_source_remove (app->timeout);
+      app->timeout = 0;
+    }
+}
+
+void
+proctable_thaw (ProcmanApp *app)
+{
+    app->timeout = g_timeout_add (app->config.update_interval,
+                                  cb_timeout,
+                                  app);
+}
+
+void
+proctable_reset_timeout (ProcmanApp *app)
+{
+    proctable_freeze (app);
+    proctable_thaw (app);
+}
