@@ -1,3 +1,4 @@
+/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <glib/gi18n.h>
@@ -651,5 +652,15 @@ namespace procman
 
 }
 
-
-
+void
+bind_column_to_gsetting (GSettings *settings, GtkTreeViewColumn *column)
+{
+    char *key;
+    gint column_id = gtk_tree_view_column_get_sort_column_id(column);
+    key = g_strdup_printf ("col-%d-width", column_id);
+    g_settings_bind (settings, key, column, "fixed-width", G_SETTINGS_BIND_DEFAULT);
+    g_free (key);
+    key = g_strdup_printf ("col-%d-visible", column_id);
+    g_settings_bind (settings, key, column, "visible", G_SETTINGS_BIND_DEFAULT);
+    g_free (key);
+}
